@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2023 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -21,6 +21,7 @@ import platform
 import hashlib
 import sqlite3
 from pathlib import Path
+import re
 
 from . import s_log , s_config , s_util
 
@@ -85,6 +86,10 @@ def filepath_get( ) :
     fp = filedir_get( ) + fn
     if not os.path.isfile( fp ) :
         dbcon = sqlite3.connect( fp )
+
+        dbcur = dbcon.cursor( )
+        dbcur.execute( "pragma journal_mode=wal" )
+
         dbcon.commit( )
         dbcon.close( )
         init_schema( )
@@ -108,6 +113,7 @@ def sql_execute( sql , params_tuple = False ) :
 
     dbcon = sqlite3.connect( filepath_get( ) )
     cur = dbcon.cursor( )
+    cur.execute( "pragma synchronous=NORMAL" )
     if params_tuple == False:
         cur.execute( sql )
     else:
@@ -124,6 +130,7 @@ def sql_execute_fetch( sql , fetch_all = False ) :
     dbcon = sqlite3.connect( filepath_get( ) )
     dbcon.row_factory = lambda C , R : { c[ 0 ] : R[ i ] for i , c in enumerate( C.description ) }
     cur = dbcon.cursor( )
+    cur.execute( "pragma synchronous=NORMAL" )
     cur.execute( sql )
 
     if fetch_all : 
@@ -228,6 +235,7 @@ def table_readall( t , extra = "" ) :
 def table_truncate( t , extra = "" ) :
     sql = "DELETE from " + t + " " + extra
     sql_execute( sql )
+    sql_execute( "VACUUM" )
 
 def table_rowcount( t , extra = "") :
     sql = "SELECT COUNT(*) as count FROM " + t + " " + extra
@@ -582,7 +590,7 @@ def stdio_get_stdout( ) :
 
 ####################################################################
 
-def files_create( fp , trimpath = "" ) :
+def files_create( fp , trimpath = "" , run_macro = False ) :
 
     # FIXME TODO have some restriction paths allowed - this breaks when creating UID directories for work spaces
     # FIXME TODO add tests for this...
@@ -601,11 +609,36 @@ def files_create( fp , trimpath = "" ) :
 
     ####################################################################
 
-    # FIXME TODO WARNING only for HTML files and given macro name
-    if( s_util.path_ext( fp ) == ".html" ) :
-        fc = fc.decode( "utf8" ).replace( "_SAPI_DB_FILES_MACRO_HTML_CACHEBUST_" , s_util.time_hexepoch_str( ) ).encode( "utf8" )
+    if run_macro :
+
+        if( s_util.path_ext( fp ) in [ ".php" , ".html" , ".js" , ".css" , ".py" ] ) :
+            fc_decoded = fc.decode( "utf8" )
+
+            # FIXME TODO this can be done once...?
+            pattern = re.compile(r'_SAPI_DB_FILES_MACRO_ENV_:::(.+?):::')
+            for match in pattern.finditer(fc_decoded):
+                match_key = match.group(1)
+                s_log.write(match_key)
+                match_key_env=s_util.environ_get(match_key)
+                s_log.write(match_key_env)
+                if match_key_env :
+                    text_from="_SAPI_DB_FILES_MACRO_ENV_:::"+match_key+":::"
+                    text_to=match_key_env
+                    s_log.write( text_from + " -> " + text_to )
+                    fc_decoded = fc_decoded.replace( text_from , text_to )
+
+
+            #if "_SAPI_DB_FILES_MACRO_ENV_" in fc_decoded :
+            #    s_log.write("YEA")
+            #    found = re.search(r'_SAPI_DB_FILES_MACRO_ENV_:::(.+?):::', fc_decoded)
+            #   s_log.write(found.groups())
+
+
+
+
+            fc_decoded = fc_decoded.replace( "_SAPI_DB_FILES_MACRO_HTML_CACHEBUST_" , s_util.time_hexepoch_str( ) )
+            fc = fc_decoded.encode( "utf8" )
 
-    #print( fp )
 
     ####################################################################
     
@@ -728,15 +761,15 @@ def files_write( fp_source , fp_target = False ) :
     fp_target_tmp = fp_target + s_util.uhash( )
 
     with open( fp_target_tmp , "wb" ) as f :
-        if type(fd[ "fc" ]) is str:
-            fd[ "fc" ]=fd[ "fc" ].encode()
+        if type( fd[ "fc" ] ) is str :
+            fd[ "fc" ] = fd[ "fc" ].encode( )
 
         f.write( fd[ "fc" ] )
         f.flush( )
 
     s_util.file_replace( fp_target_tmp , fp_target )
 
-    s_util.file_settimes( fp_target , fd[ "fm" ] )
+    #s_util.file_settimes( fp_target , fd[ "fm" ] )
 
 
 def files_append( fp_source , fp_target = False ) :
@@ -770,7 +803,7 @@ def files_append( fp_source , fp_target = False ) :
 
         s_util.file_replace( fp_target_tmp , fp_target )
 
-    s_util.file_settimes( fp_target , fd[ "fm" ] )
+    #s_util.file_settimes( fp_target , fd[ "fm" ] )
 
 
 # with open( dir_cache + "local_out.png" , "wb" ) as f :
@@ -812,7 +845,7 @@ def files_restore( rpath = False , mode = "overwrite" ) :
 
 #        s_util.file_settimes(fp_target,db_file["fm"])
 
-def files_createall( pat , trim_path = True ) :
+def files_createall( pat , trim_path = True , run_macro = False ) :
     # Let's be clever and try to trim the pattern matching directory...
 
     # FIXME TODO be careful... we are only checking for wildcard "**"
@@ -825,7 +858,7 @@ def files_createall( pat , trim_path = True ) :
     files = s_util.glob_files( pat , True )
     for f in files :
         if os.path.isfile( f ) :
-            files_create( f , pat_trim )
+            files_create( f , pat_trim , run_macro )
 
 
 
