@@ -7,7 +7,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2023 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -86,9 +86,10 @@ def write( msg_raw , consoleprint = False ) :
         # FIXME TODO use util json note numpy stuff
         msg = json.dumps( msg , default = default_json , indent = 4 , sort_keys = True )
 
-    if( isinstance( msg , ( int , float , bool , os._Environ ) ) ) :
+    if( isinstance( msg , ( int , float , bool , tuple , os._Environ ) ) ) :
         msg = str( msg )
 
+
     cf = currentframe( ).f_back
 
     frameinfo = getframeinfo( cf )
