@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2023 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -28,6 +28,7 @@ import glob
 import traceback
 import random
 import sqlite3
+import copy
 
 import atexit
 
@@ -36,7 +37,6 @@ import threading
 from datetime import datetime , timedelta , timezone
 
 import datetime as _dt
-import dateutil.parser
 
 from subprocess import Popen, PIPE
 
@@ -57,6 +57,17 @@ from . import get_version , s_log , s_config , s_net , s_db
 #        else :
 #            return super( ).default( z )
 
+
+#class CustomJSONEncoder(json.JSONEncoder):
+#    def default(self, obj):
+#        if isinstance(obj, datetime):
+#            return obj.isoformat()
+#        if isinstance(obj, np.ndarray):
+#           return obj.tolist()
+#        if isinstance(obj, OrderedDict):
+#           return "{" + ",".join([self.encode(k) + ":" + self.encode(v) for (k, v) in obj.iteritems()]) + "}"
+#        return json.JSONEncoder.default(self, obj)
+
 class JsonEncoder( json.JSONEncoder ) :
 
     def default( self , obj ) :
@@ -114,11 +125,80 @@ def json_prettyprint( data ) :
 
 #####################################################################
 
-def db_getcon( db_fp ) :
-    db_con = sqlite3.connect( db_fp )
+
+def sdb_init( db_fp ) :
+    if not os.path.exists( db_fp ) :
+
+        db_con = sqlite3.connect( db_fp )
+
+        if( db_con.total_changes != 0 ) :
+            print( "ERROR db_con.total_changes ! 0 " )
+            time.sleep( 10 )
+            sys.exit( )
+
+        db_cur = db_con.cursor( )
+        db_cur.execute( "pragma journal_mode=wal" )
+
+        db_con.commit( )
+        db_con.close( )
+        return(False)
+    return(True)
+
+def sdb_execute( db_fp , sql , params_tuple = False ) :
+
+    db_con = sqlite3.connect( db_fp , isolation_level = None )
+    db_cur = db_con.cursor( )
+    db_cur.execute( "pragma synchronous=NORMAL" )
+    if params_tuple == False :
+        db_cur.execute( sql )
+    else :
+        db_cur.execute( sql , params_tuple )
+    db_con.commit( )
+    db_con.close( )
+
+def sdb_execute_fetch( db_fp , sql , fetch_all = False , params_tuple=False) :
+
+    #s_log.write( sql )
+
+    dbcon = sqlite3.connect( db_fp , isolation_level = None  )
+    dbcon.row_factory = lambda C , R : { c[ 0 ] : R[ i ] for i , c in enumerate( C.description ) }
+    db_cur = dbcon.cursor( )
+    db_cur.execute( "pragma synchronous=NORMAL" )
+
+    if params_tuple == False :
+        db_cur.execute( sql )
+    else :
+        db_cur.execute( sql , params_tuple )
+
+    #db_cur.execute( sql )
+
+    if fetch_all : 
+        rows = db_cur.fetchall( )
+        dbcon.close( )
+        return( rows )
+    else :
+        row = db_cur.fetchone( )
+        dbcon.close( )
+        if( not row ) : return( False )
+        return( row )
+
 
 #####################################################################
 
+def copy_deep( x ) :
+    return( copy.deepcopy( x ) )
+
+#####################################################################
+
+def is_number(n):
+    is_number = True
+    try:
+        num = float(n)
+        is_number = num == num   
+    except ValueError:
+        is_number = False
+    return is_number
+
 def atexit_register( f ) :
     atexit.register( f )
 
@@ -138,6 +218,9 @@ def num_randomlist( s = 10 ) :
     random_list = [ random.random( ) for i in range( s ) ]
     return( random_list )
 
+def rnd_binary( s = 1024 ) :
+    return( os.urandom( s ) )
+
 # Get arg from position and use default
 def argv_get( p , d = None ) :
     al = len( sys.argv ) - 1
@@ -565,8 +648,15 @@ def display_time( seconds , granularity = 2 ) :
     return ', '.join( result[ :granularity ] )
 
 
-def datetimestr_to_unixtime(dt_str):
-    return(dateutil.parser.parse(dt_str).timestamp())
+def datetimestr_to_unixtime( dt_str ) :
+    if(dt_str.endswith("Z")):
+        dt_str=dt_str[:-1]
+
+    if(len(dt_str)==19):
+        dt_str=dt_str+"+00:00"
+
+    parsedDate = datetime.fromisoformat(dt_str)
+    return( int( parsedDate.timestamp( ) ) )
 
 
 def datetime_strtotimestampms( dtstr ) :
@@ -602,7 +692,7 @@ def time_now_str( ) :
     return( str( round( time_now( ) ) ) )
 
 def time_hexepoch_str( ) :
-    return( hex( round( time_now( ) - 1664792185 ) )[ 2: ] )
+    return( hex( round( time_now( ) - 1666275269 ) )[ 2: ] )
 
 def datetime_utcnow( ) :
     return( datetime.utcnow( ) )
@@ -615,7 +705,7 @@ def datetime_utctimestamp( ) :
     return( datetime.utcnow( ).timestamp( ) )
 
 def url_parse( u ) :
-    return(urllib.parse.urlparse(u))
+    return( urllib.parse.urlparse( u ) )
 
 
 def sleep( t = 1 ) :
@@ -737,6 +827,9 @@ def file_getcontent( fn , scp ) :
     return( contents )
 
 
+def file_readlines( fp ) :
+    return( open( fp , "r" ).read( ).splitlines( ) )
+
 def file_read( fp ) :
     return( open( fp , "r" ).read( ) )
 
