@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2023 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -52,10 +52,10 @@ def exitiferror( ) :
     if( geterror( ) ) :
         prexit( geterror( ) )
 
-def defdata( raw=False ) :
+def defdata( raw = False ) :
     return( s_db.meta_read( "_data" , raw ) )
 
-def defmeta( raw=False) :
+def defmeta( raw = False) :
     return( s_db.meta_read( "_meta" , raw ) )
 
 def geterror( ) :
@@ -304,3 +304,37 @@ def run( params = { } , wait_timeout = 60 ) :
     dd = defdata( )
     if( dd == False ) : return( True )
     return( dd )
+
+
+
+# Add convenience function for files update
+def run_files_update( path_source , path_target ) :
+
+    s_db.files_createall( path_source )
+
+    ####################################################################
+
+    run( {
+        "#" : {
+            "command" : "files_update" ,
+            "files_basedir" : path_target
+        } ,
+    } )
+
+    ####################################################################
+
+    err = geterror( )
+    print("AAAA")
+
+    if( err ) :
+        print("BBBB")
+        print( "CODE = " + str( err[ "code" ] ) )
+        print( "MESSAGE = " + err[ "message" ] )
+        return( False )
+
+    ####################################################################
+
+    print("CCCCC")
+    return( defdata( ) )
+
+
